@@ -1,18 +1,19 @@
 package Business::CyberSource::Response::Role::ProcessorResponse;
-use 5.008;
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = 'v0.2.5'; # VERSION
+our $VERSION = '0.007000'; # TRIAL VERSION
 
 use Moose::Role;
-use MooseX::Types::Varchar qw( Varchar );
+use MooseX::RemoteHelper;
+use MooseX::Types::CyberSource qw( _VarcharTen );
 
 has processor_response => (
-	required => 1,
-	is       => 'ro',
-	isa      => Varchar[10],
+	isa         => _VarcharTen,
+	remote_name => 'processorResponse',
+	predicate   => 'has_processor_response',
+	is          => 'ro',
 );
 
 1;
@@ -20,6 +21,7 @@ has processor_response => (
 # ABSTRACT: Processor Response attribute
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -28,7 +30,11 @@ Business::CyberSource::Response::Role::ProcessorResponse - Processor Response at
 
 =head1 VERSION
 
-version v0.2.5
+version 0.007000
+
+=head1 ATTRIBUTES
+
+=head2 processor_response
 
 =head1 BUGS
 
@@ -45,11 +51,10 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Caleb Cushing.
+This software is Copyright (c) 2012 by HostGator.com.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
