@@ -1,18 +1,18 @@
 package Business::CyberSource::Response::Role::ReconciliationID;
-use 5.008;
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = 'v0.2.5'; # VERSION
+our $VERSION = '0.007000'; # TRIAL VERSION
 
 use Moose::Role;
-use MooseX::Types::Moose qw( Int );
+use MooseX::RemoteHelper;
 
 has reconciliation_id => (
-	required => 1,
-	is       => 'ro',
-	isa      => Int,
+	isa         => 'Str',
+	remote_name => 'reconciliationID',
+	is          => 'ro',
+	predicate   => 'has_reconciliation_id',
 );
 
 1;
@@ -20,6 +20,7 @@ has reconciliation_id => (
 # ABSTRACT: Reconciliation Identifier
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -28,7 +29,11 @@ Business::CyberSource::Response::Role::ReconciliationID - Reconciliation Identif
 
 =head1 VERSION
 
-version v0.2.5
+version 0.007000
+
+=head1 ATTRIBUTES
+
+=head2 reconciliation_id
 
 =head1 BUGS
 
@@ -45,11 +50,10 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Caleb Cushing.
+This software is Copyright (c) 2012 by HostGator.com.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
