@@ -1,18 +1,19 @@
 package Business::CyberSource::Role::Currency;
-use 5.008;
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = 'v0.2.5'; # VERSION
+our $VERSION = '0.007000'; # TRIAL VERSION
 
 use Moose::Role;
+use MooseX::RemoteHelper;
 use MooseX::Types::Locale::Currency qw( CurrencyCode );
 
 has currency => (
-	required => 1,
-	is       => 'ro',
-	isa      => CurrencyCode,
+	isa         => CurrencyCode,
+	remote_name => 'currency',
+	is          => 'ro',
+	required    => 1,
 );
 
 1;
@@ -20,6 +21,7 @@ has currency => (
 # ABSTRACT: Role to apply to requests and responses that require currency
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -28,7 +30,7 @@ Business::CyberSource::Role::Currency - Role to apply to requests and responses
 
 =head1 VERSION
 
-version v0.2.5
+version 0.007000
 
 =head1 BUGS
 
@@ -45,11 +47,10 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Caleb Cushing.
+This software is Copyright (c) 2012 by HostGator.com.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
